/**
 * @file      motors_control.h
 * @author    2020 Shoji Yamamoto
 * ===============================================================
 * ALT-Groovy-PID (Version 1.0.0)
 * Copyright (c) 2020 Shoji Yamamoto
 * ===============================================================
 * The MIT License : https://opensource.org/licenses/MIT
 *
 * Copyright (c) 2020 Shoji Yamamoto
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef _MOTORS_CONTROL_H_
#define	_MOTORS_CONTROL_H_

#include <xc.h>
#include <stdint.h>

#define MOTORS_CONTROL_BIT_PST 0x80U // preset
#define MOTORS_CONTROL_BIT_BRK 0x40U // break
#define MOTORS_CONTROL_BIT_INC 0x20U // incremental option for position
#define MOTORS_CONTROL_BIT_PWM 0x01U // pwm
#define MOTORS_CONTROL_BIT_POS 0x02U // position loop

typedef uint8_t ControlMode;

#define MOTORS_CONTROL_MODE_NONE 0
#define MOTORS_CONTROL_MODE_BRK  MOTORS_CONTROL_BIT_BRK
#define MOTORS_CONTROL_MODE_PST  MOTORS_CONTROL_BIT_PST
#define MOTORS_CONTROL_MODE_PWM  MOTORS_CONTROL_BIT_PWM 
#define MOTORS_CONTROL_MODE_POS  (MOTORS_CONTROL_BIT_PWM|MOTORS_CONTROL_BIT_POS)


#define MOTORS_CONTROL_MOTOR_COUNT 2

#ifdef	__cplusplus
extern "C" {
#endif /* __cplusplus */

    extern void motors_control_init(void);
    extern inline void motors_control_isr(void);
    extern void motors_control_set_command(int8_t idx, ControlMode mode, int16_t target);
    extern void motors_control_execute(void);
    extern uint16_t motors_control_feedback(void);
    extern uint16_t motors_control_get_cycle_of_last_command(int8_t idx);
    extern ControlMode motors_control_get_mode(int8_t idx);
    extern int16_t motors_control_get_actual_position(int8_t idx);
    extern int16_t motors_control_get_demand_position(int8_t idx);
    extern int16_t motors_control_get_demand_pwm(int8_t idx);

#ifdef	__cplusplus
}
#endif /* __cplusplus */

#endif	/* _MOTORS_CONTROL_H_ */

